# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: storage.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rstorage.proto\x12\x07storage\x1a\x0evalidate.proto\"%\n\x07Storage\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\xa8\x01\n\x06Object\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04type\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06prefix\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04size\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x19\n\x0clastmodified\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x07\n\x05_nameB\x07\n\x05_typeB\t\n\x07_prefixB\x07\n\x05_sizeB\x0f\n\r_lastmodified\"k\n\x14StorageResponseError\x12(\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.storage.StorageErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"i\n\x13ObjectResponseError\x12\'\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x14.storage.ObjectErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"\x80\x01\n%ObjectStorageCredentialsResponseError\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x19.storage.CredentialsErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"y\n\x12StorageListRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12$\n\x06object\x18\x02 \x01(\x0b\x32\x0f.storage.ObjectH\x01\x88\x01\x01\x42\n\n\x08_storageB\t\n\x07_object\"u\n\x13StorageListResponse\x12!\n\x07storage\x18\x01 \x03(\x0b\x32\x10.storage.Storage\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.storage.StorageResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"J\n\x14StorageCreateRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x42\n\n\x08_storage\"\x88\x01\n\x15StorageCreateResponse\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.storage.StorageResponseErrorH\x01\x88\x01\x01\x42\n\n\x08_storageB\x08\n\x06_error\"J\n\x14StorageDeleteRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x42\n\n\x08_storage\"T\n\x15StorageDeleteResponse\x12\x31\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1d.storage.StorageResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x7f\n\x18StorageListObjectRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12$\n\x06object\x18\x02 \x01(\x0b\x32\x0f.storage.ObjectH\x01\x88\x01\x01\x42\n\n\x08_storageB\t\n\x07_object\"y\n\x19StorageListObjectResponse\x12\x1f\n\x06object\x18\x01 \x03(\x0b\x32\x0f.storage.Object\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.storage.StorageResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"z\n\x13ObjectCreateRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12$\n\x06object\x18\x02 \x01(\x0b\x32\x0f.storage.ObjectH\x01\x88\x01\x01\x42\n\n\x08_storageB\t\n\x07_object\"R\n\x14ObjectCreateResponse\x12\x30\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1c.storage.ObjectResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"x\n\x11ObjectListRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12$\n\x06object\x18\x02 \x01(\x0b\x32\x0f.storage.ObjectH\x01\x88\x01\x01\x42\n\n\x08_storageB\t\n\x07_object\"q\n\x12ObjectListResponse\x12\x1f\n\x06object\x18\x01 \x03(\x0b\x32\x0f.storage.Object\x12\x30\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1c.storage.ObjectResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"w\n\x10ObjectGetRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12$\n\x06object\x18\x02 \x01(\x0b\x32\x0f.storage.ObjectH\x01\x88\x01\x01\x42\n\n\x08_storageB\t\n\x07_object\"\x80\x01\n\x11ObjectGetResponse\x12$\n\x06object\x18\x01 \x01(\x0b\x32\x0f.storage.ObjectH\x00\x88\x01\x01\x12\x30\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1c.storage.ObjectResponseErrorH\x01\x88\x01\x01\x42\t\n\x07_objectB\x08\n\x06_error\"F\n\x13ObjectDeleteRequest\x12$\n\x06object\x18\x01 \x01(\x0b\x32\x0f.storage.ObjectH\x00\x88\x01\x01\x42\t\n\x07_object\"R\n\x14ObjectDeleteResponse\x12\x30\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1c.storage.ObjectResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x9e\x02\n\x1aObjectStorageS3Credentials\x12\x19\n\x0c\x65ndpoint_url\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bregion_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\raccess_key_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nsecret_key\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rsession_token\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x17\n\nexpiration\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\x0f\n\r_endpoint_urlB\x0e\n\x0c_region_nameB\x10\n\x0e_access_key_idB\r\n\x0b_secret_keyB\x10\n\x0e_session_tokenB\r\n\x0b_expiration\"\xa1\x01\n\x1dObjectStorageAzureCredentials\x12\x19\n\x0c\x65ndpoint_url\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\raccess_key_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nsecret_key\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0f\n\r_endpoint_urlB\x10\n\x0e_access_key_idB\r\n\x0b_secret_key\"K\n\x18ObjectStorageCredentials\x12/\n\x02s3\x18\x01 \x01(\x0b\x32#.storage.ObjectStorageS3Credentials\"U\n\x1fObjectStorageCredentialsRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x42\n\n\x08_storage\"\xbd\x01\n ObjectStorageCredentialsResponse\x12;\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32!.storage.ObjectStorageCredentialsH\x00\x88\x01\x01\x12\x42\n\x05\x65rror\x18\x02 \x01(\x0b\x32..storage.ObjectStorageCredentialsResponseErrorH\x01\x88\x01\x01\x42\x0e\n\x0c_credentialsB\x08\n\x06_error*r\n\x0cStorageError\x12\x14\n\x10STORAGE_NO_ERROR\x10\x00\x12\x19\n\x15STORAGE_ALREADY_EXIST\x10\x01\x12\x15\n\x11STORAGE_NOT_FOUND\x10\x02\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xe8\x07*\x83\x01\n\x0bObjectError\x12\x13\n\x0fOBJECT_NO_ERROR\x10\x00\x12\x18\n\x14OBJECT_ALREADY_EXIST\x10\x01\x12\x15\n\x11OBJECT_SIZE_ERROR\x10\x02\x12\x14\n\x10OBJECT_NOT_FOUND\x10\x03\x12\x18\n\x14OBJECT_DIR_NOT_EMPTY\x10\x04*,\n\x10\x43redentialsError\x12\x18\n\x14\x43REDENTIALS_NO_ERROR\x10\x00\x42\x30Z.github.com/jupyter-naas/naas-models/go/storageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'storage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/jupyter-naas/naas-models/go/storage'
  _globals['_STORAGEERROR']._serialized_start=3132
  _globals['_STORAGEERROR']._serialized_end=3246
  _globals['_OBJECTERROR']._serialized_start=3249
  _globals['_OBJECTERROR']._serialized_end=3380
  _globals['_CREDENTIALSERROR']._serialized_start=3382
  _globals['_CREDENTIALSERROR']._serialized_end=3426
  _globals['_STORAGE']._serialized_start=42
  _globals['_STORAGE']._serialized_end=79
  _globals['_OBJECT']._serialized_start=82
  _globals['_OBJECT']._serialized_end=250
  _globals['_STORAGERESPONSEERROR']._serialized_start=252
  _globals['_STORAGERESPONSEERROR']._serialized_end=359
  _globals['_OBJECTRESPONSEERROR']._serialized_start=361
  _globals['_OBJECTRESPONSEERROR']._serialized_end=466
  _globals['_OBJECTSTORAGECREDENTIALSRESPONSEERROR']._serialized_start=469
  _globals['_OBJECTSTORAGECREDENTIALSRESPONSEERROR']._serialized_end=597
  _globals['_STORAGELISTREQUEST']._serialized_start=599
  _globals['_STORAGELISTREQUEST']._serialized_end=720
  _globals['_STORAGELISTRESPONSE']._serialized_start=722
  _globals['_STORAGELISTRESPONSE']._serialized_end=839
  _globals['_STORAGECREATEREQUEST']._serialized_start=841
  _globals['_STORAGECREATEREQUEST']._serialized_end=915
  _globals['_STORAGECREATERESPONSE']._serialized_start=918
  _globals['_STORAGECREATERESPONSE']._serialized_end=1054
  _globals['_STORAGEDELETEREQUEST']._serialized_start=1056
  _globals['_STORAGEDELETEREQUEST']._serialized_end=1130
  _globals['_STORAGEDELETERESPONSE']._serialized_start=1132
  _globals['_STORAGEDELETERESPONSE']._serialized_end=1216
  _globals['_STORAGELISTOBJECTREQUEST']._serialized_start=1218
  _globals['_STORAGELISTOBJECTREQUEST']._serialized_end=1345
  _globals['_STORAGELISTOBJECTRESPONSE']._serialized_start=1347
  _globals['_STORAGELISTOBJECTRESPONSE']._serialized_end=1468
  _globals['_OBJECTCREATEREQUEST']._serialized_start=1470
  _globals['_OBJECTCREATEREQUEST']._serialized_end=1592
  _globals['_OBJECTCREATERESPONSE']._serialized_start=1594
  _globals['_OBJECTCREATERESPONSE']._serialized_end=1676
  _globals['_OBJECTLISTREQUEST']._serialized_start=1678
  _globals['_OBJECTLISTREQUEST']._serialized_end=1798
  _globals['_OBJECTLISTRESPONSE']._serialized_start=1800
  _globals['_OBJECTLISTRESPONSE']._serialized_end=1913
  _globals['_OBJECTGETREQUEST']._serialized_start=1915
  _globals['_OBJECTGETREQUEST']._serialized_end=2034
  _globals['_OBJECTGETRESPONSE']._serialized_start=2037
  _globals['_OBJECTGETRESPONSE']._serialized_end=2165
  _globals['_OBJECTDELETEREQUEST']._serialized_start=2167
  _globals['_OBJECTDELETEREQUEST']._serialized_end=2237
  _globals['_OBJECTDELETERESPONSE']._serialized_start=2239
  _globals['_OBJECTDELETERESPONSE']._serialized_end=2321
  _globals['_OBJECTSTORAGES3CREDENTIALS']._serialized_start=2324
  _globals['_OBJECTSTORAGES3CREDENTIALS']._serialized_end=2610
  _globals['_OBJECTSTORAGEAZURECREDENTIALS']._serialized_start=2613
  _globals['_OBJECTSTORAGEAZURECREDENTIALS']._serialized_end=2774
  _globals['_OBJECTSTORAGECREDENTIALS']._serialized_start=2776
  _globals['_OBJECTSTORAGECREDENTIALS']._serialized_end=2851
  _globals['_OBJECTSTORAGECREDENTIALSREQUEST']._serialized_start=2853
  _globals['_OBJECTSTORAGECREDENTIALSREQUEST']._serialized_end=2938
  _globals['_OBJECTSTORAGECREDENTIALSRESPONSE']._serialized_start=2941
  _globals['_OBJECTSTORAGECREDENTIALSRESPONSE']._serialized_end=3130
# @@protoc_insertion_point(module_scope)
