# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: errors.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x65rrors.proto\x12\x06\x65rrors\x1a\x0evalidate.proto\"\\\n\rErrorResponse\x12 \n\x04\x63ode\x18\x01 \x01(\x0e\x32\r.errors.ErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message*\xcc\x06\n\x05\x45rror\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xc7\x01\x12\x17\n\x12IAM_USER_NOT_FOUND\x10\xc8\x01\x12\x1c\n\x17IAM_USER_NOT_AUTHORIZED\x10\xc9\x01\x12\x1f\n\x1aIAM_API_KEY_ALREADY_EXISTS\x10\xca\x01\x12\x18\n\x13WORKSPACE_NOT_FOUND\x10\xac\x02\x12\"\n\x1dWORKSPACE_USER_ALREADY_EXISTS\x10\xae\x02\x12\x1d\n\x18WORKSPACE_USER_NOT_FOUND\x10\xaf\x02\x12\"\n\x1dWORKSPACE_USER_ALREADY_ACTIVE\x10\xb0\x02\x12\x33\n.WORKSPACE_USER_ALREADY_HAVE_PERSONAL_WORKSPACE\x10\xb1\x02\x12\x1f\n\x1aWORKSPACE_PLUGIN_NOT_FOUND\x10\xb2\x02\x12\x1d\n\x18WORKSPACE_INVITE_INVALID\x10\xb3\x02\x12\x32\n-WORKSPACE_CANNOT_INVITE_TO_PERSONAL_WORKSPACE\x10\xb4\x02\x12\x1f\n\x1a\x43REDITS_USER_HAS_NO_PARENT\x10\x90\x03\x12\x1b\n\x16\x43REDITS_OUT_OF_CREDITS\x10\x91\x03\x12\x17\n\x12ONTOLOGY_NOT_FOUND\x10\xf4\x03\x12\x13\n\x0e\x43HAT_NOT_FOUND\x10\xd8\x04\x12\x18\n\x13\x43HAT_NOT_AUTHORIZED\x10\xd9\x04\x12+\n&CHAT_COMPLETION_ADAPTOR_DOES_NOT_EXIST\x10\xda\x04\x12!\n\x1c\x43HAT_CONTEXT_LENGTH_EXCEEDED\x10\xdb\x04\x12 \n\x1b\x43HAT_MESSAGE_ALREADY_EXISTS\x10\xdc\x04\x12\x1b\n\x16\x43HAT_MESSAGE_NOT_FOUND\x10\xdd\x04\x12\x1f\n\x1a\x43HAT_INTERNAL_SERVER_ERROR\x10\xbb\x05\x12\x16\n\x11\x41IMODEL_NOT_FOUND\x10\xbc\x05\x12\x14\n\x0f\x41SSET_NOT_FOUND\x10\xa0\x06\x12\x19\n\x14\x41SSET_ALREADY_EXISTS\x10\xa1\x06\x12\x18\n\x13\x41SSET_REQUEST_ERROR\x10\xa2\x06\x42/Z-github.com/jupyter-naas/naas-models/go/errorsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'errors_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/jupyter-naas/naas-models/go/errors'
  _globals['_ERROR']._serialized_start=135
  _globals['_ERROR']._serialized_end=979
  _globals['_ERRORRESPONSE']._serialized_start=40
  _globals['_ERRORRESPONSE']._serialized_end=132
# @@protoc_insertion_point(module_scope)
