# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csecret.proto\x12\x07secrets\x1a\x0evalidate.proto\"B\n\x06Secret\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\"k\n\x13SecretResponseError\x12(\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x14.secrets.SecretErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\n\n\x08_message\"F\n\x13SecretCreateRequest\x12$\n\x06secret\x18\x01 \x01(\x0b\x32\x0f.secrets.SecretH\x00\x88\x01\x01\x42\t\n\x07_secret\"R\n\x14SecretCreateResponse\x12\x30\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\".\n\x10SecretGetRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\x80\x01\n\x11SecretGetResponse\x12$\n\x06secret\x18\x01 \x01(\x0b\x32\x0f.secrets.SecretH\x00\x88\x01\x01\x12\x30\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x01\x88\x01\x01\x42\t\n\x07_secretB\x08\n\x06_error\"1\n\x13SecretDeleteRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"R\n\x14SecretDeleteResponse\x12\x30\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"c\n\x11SecretListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"r\n\x12SecretListResponse\x12 \n\x07secrets\x18\x01 \x03(\x0b\x32\x0f.secrets.Secret\x12\x30\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\";\n\x17SecretBulkCreateRequest\x12 \n\x07secrets\x18\x01 \x03(\x0b\x32\x0f.secrets.Secret\"G\n\x18SecretBulkCreateResponse\x12+\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x1c.secrets.SecretResponseError*s\n\x0bSecretError\x12\x13\n\x0fSECRET_NO_ERROR\x10\x00\x12\x19\n\x15SECRET_ALREADY_EXISTS\x10\x01\x12\x14\n\x10SECRET_NOT_FOUND\x10\x02\x12\x1e\n\x1aSECRET_MARKED_FOR_DELETION\x10\x03\x42\x30Z.github.com/jupyter-naas/naas-models/go/secretsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/jupyter-naas/naas-models/go/secrets'
  _globals['_SECRETERROR']._serialized_start=1039
  _globals['_SECRETERROR']._serialized_end=1154
  _globals['_SECRET']._serialized_start=41
  _globals['_SECRET']._serialized_end=107
  _globals['_SECRETRESPONSEERROR']._serialized_start=109
  _globals['_SECRETRESPONSEERROR']._serialized_end=216
  _globals['_SECRETCREATEREQUEST']._serialized_start=218
  _globals['_SECRETCREATEREQUEST']._serialized_end=288
  _globals['_SECRETCREATERESPONSE']._serialized_start=290
  _globals['_SECRETCREATERESPONSE']._serialized_end=372
  _globals['_SECRETGETREQUEST']._serialized_start=374
  _globals['_SECRETGETREQUEST']._serialized_end=420
  _globals['_SECRETGETRESPONSE']._serialized_start=423
  _globals['_SECRETGETRESPONSE']._serialized_end=551
  _globals['_SECRETDELETEREQUEST']._serialized_start=553
  _globals['_SECRETDELETEREQUEST']._serialized_end=602
  _globals['_SECRETDELETERESPONSE']._serialized_start=604
  _globals['_SECRETDELETERESPONSE']._serialized_end=686
  _globals['_SECRETLISTREQUEST']._serialized_start=688
  _globals['_SECRETLISTREQUEST']._serialized_end=787
  _globals['_SECRETLISTRESPONSE']._serialized_start=789
  _globals['_SECRETLISTRESPONSE']._serialized_end=903
  _globals['_SECRETBULKCREATEREQUEST']._serialized_start=905
  _globals['_SECRETBULKCREATEREQUEST']._serialized_end=964
  _globals['_SECRETBULKCREATERESPONSE']._serialized_start=966
  _globals['_SECRETBULKCREATERESPONSE']._serialized_end=1037
# @@protoc_insertion_point(module_scope)
