# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ontology.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2
import p2p_validate_pb2 as p2p__validate__pb2
import errors_pb2 as errors__pb2
import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eontology.proto\x12\x08ontology\x1a\x0evalidate.proto\x1a\x12p2p_validate.proto\x1a\x0c\x65rrors.proto\x1a\x0c\x63ommon.proto\"\xd2\x02\n\x08Ontology\x12\x14\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x12\n\x05label\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06source\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0c\x64ownload_url\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08logo_url\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x12\n\x05level\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x16\n\tis_public\x18\t \x01(\x08H\x07\x88\x01\x01\x42\x0f\n\r_workspace_idB\x08\n\x06_labelB\t\n\x07_sourceB\x0f\n\r_download_urlB\x0e\n\x0c_descriptionB\x0b\n\t_logo_urlB\x08\n\x06_levelB\x0c\n\n_is_public\"\xb9\x02\n\x0fOntologySummary\x12\x14\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x12\n\x05label\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x19\n\x0c\x64ownload_url\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08logo_url\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x12\n\x05level\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tis_public\x18\x08 \x01(\x08H\x06\x88\x01\x01\x42\x0f\n\r_workspace_idB\x08\n\x06_labelB\x0f\n\r_download_urlB\x0e\n\x0c_descriptionB\x0b\n\t_logo_urlB\x08\n\x06_levelB\x0c\n\n_is_public\"\xbc\x02\n\x10OntologyCreation\x12&\n\x0cworkspace_id\x18\x01 \x01(\tB\x10\xfa\x42\x05r\x03\xb0\x01\x01\x8a\x43\x05r\x03\x98\x02\x01\x12!\n\x05label\x18\x02 \x01(\tB\x12\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x8a\x43\x05r\x03\x98\x02\x01\x12\x1f\n\x06source\x18\x03 \x01(\tB\x0f\xfa\x42\x04r\x02\x10\x01\x8a\x43\x05r\x03\x98\x02\x01\x12\x19\n\x0c\x64ownload_url\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08logo_url\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05level\x18\x07 \x01(\tH\x03\x88\x01\x01\x12\x16\n\tis_public\x18\x08 \x01(\x08H\x04\x88\x01\x01\x42\x0f\n\r_download_urlB\x0e\n\x0c_descriptionB\x0b\n\t_logo_urlB\x08\n\x06_levelB\x0c\n\n_is_public\"\x87\x03\n\x0eOntologyUpdate\x12\x1c\n\x02id\x18\x01 \x01(\tB\x10\xfa\x42\x05r\x03\xb0\x01\x01\x8a\x43\x05r\x03\x98\x02\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x12\n\x05label\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06source\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0c\x64ownload_url\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08logo_url\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x12\n\x05level\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x16\n\tis_public\x18\t \x01(\x08H\x07\x88\x01\x01\x12%\n\nfield_mask\x18\x64 \x01(\x0b\x32\x11.common.FieldMaskB\x0f\n\r_workspace_idB\x08\n\x06_labelB\t\n\x07_sourceB\x0f\n\r_download_urlB\x0e\n\x0c_descriptionB\x0b\n\t_logo_urlB\x08\n\x06_levelB\x0c\n\n_is_public\"\x89\x01\n\x13OntologyListRequest\x12&\n\x0cworkspace_id\x18\x01 \x01(\tB\x10\xfa\x42\x05r\x03\xb0\x01\x01\x8a\x43\x05r\x03\x98\x02\x01\x12$\n\tpage_size\x18\x02 \x01(\x05\x42\x11\xfa\x42\x06\x1a\x04\x18\x64(\x01\x8a\x43\x05\x1a\x03\xa8\x01\x01\x12$\n\x0bpage_number\x18\x03 \x01(\x05\x42\x0f\xfa\x42\x04\x1a\x02(\x00\x8a\x43\x05\x1a\x03\xa8\x01\x01\"z\n\x14OntologyListResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12-\n\nontologies\x18\x02 \x03(\x0b\x32\x19.ontology.OntologySummaryB\x08\n\x06_error\"`\n\x12OntologyGetRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x82\x01\n\x13OntologyGetResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12)\n\x08ontology\x18\x02 \x01(\x0b\x32\x12.ontology.OntologyH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_ontology\"G\n\x17OntologyCreationRequest\x12,\n\x08ontology\x18\x01 \x01(\x0b\x32\x1a.ontology.OntologyCreation\"\x87\x01\n\x18OntologyCreationResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12)\n\x08ontology\x18\x02 \x01(\x0b\x32\x12.ontology.OntologyH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_ontology\"C\n\x15OntologyUpdateRequest\x12*\n\x08ontology\x18\x01 \x01(\x0b\x32\x18.ontology.OntologyUpdate\"\x85\x01\n\x16OntologyUpdateResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12)\n\x08ontology\x18\x02 \x01(\x0b\x32\x12.ontology.OntologyH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_ontology\"O\n\x17OntologyDeletionRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12\x1e\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\"O\n\x18OntologyDeletionResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error2\x95\x03\n\x0fOntologyService\x12G\n\x04List\x12\x1d.ontology.OntologyListRequest\x1a\x1e.ontology.OntologyListResponse\"\x00\x12\x44\n\x03Get\x12\x1c.ontology.OntologyGetRequest\x1a\x1d.ontology.OntologyGetResponse\"\x00\x12Q\n\x06\x43reate\x12!.ontology.OntologyCreationRequest\x1a\".ontology.OntologyCreationResponse\"\x00\x12M\n\x06Update\x12\x1f.ontology.OntologyUpdateRequest\x1a .ontology.OntologyUpdateResponse\"\x00\x12Q\n\x06\x44\x65lete\x12!.ontology.OntologyDeletionRequest\x1a\".ontology.OntologyDeletionResponse\"\x00\x42\x31Z/github.com/jupyter-naas/naas-models/go/ontologyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ontology_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/jupyter-naas/naas-models/go/ontology'
  _globals['_ONTOLOGY'].fields_by_name['id']._loaded_options = None
  _globals['_ONTOLOGY'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGY'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGY'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYSUMMARY'].fields_by_name['id']._loaded_options = None
  _globals['_ONTOLOGYSUMMARY'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYSUMMARY'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYSUMMARY'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYCREATION'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYCREATION'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001\212C\005r\003\230\002\001'
  _globals['_ONTOLOGYCREATION'].fields_by_name['label']._loaded_options = None
  _globals['_ONTOLOGYCREATION'].fields_by_name['label']._serialized_options = b'\372B\007r\005\020\001\030\377\001\212C\005r\003\230\002\001'
  _globals['_ONTOLOGYCREATION'].fields_by_name['source']._loaded_options = None
  _globals['_ONTOLOGYCREATION'].fields_by_name['source']._serialized_options = b'\372B\004r\002\020\001\212C\005r\003\230\002\001'
  _globals['_ONTOLOGYUPDATE'].fields_by_name['id']._loaded_options = None
  _globals['_ONTOLOGYUPDATE'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001\212C\005r\003\230\002\001'
  _globals['_ONTOLOGYUPDATE'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYUPDATE'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001\212C\005r\003\230\002\001'
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['page_size']._serialized_options = b'\372B\006\032\004\030d(\001\212C\005\032\003\250\001\001'
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['page_number']._loaded_options = None
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['page_number']._serialized_options = b'\372B\004\032\002(\000\212C\005\032\003\250\001\001'
  _globals['_ONTOLOGYGETREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_ONTOLOGYGETREQUEST'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYDELETIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_ONTOLOGYDELETIONREQUEST'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYDELETIONREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYDELETIONREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGY']._serialized_start=93
  _globals['_ONTOLOGY']._serialized_end=431
  _globals['_ONTOLOGYSUMMARY']._serialized_start=434
  _globals['_ONTOLOGYSUMMARY']._serialized_end=747
  _globals['_ONTOLOGYCREATION']._serialized_start=750
  _globals['_ONTOLOGYCREATION']._serialized_end=1066
  _globals['_ONTOLOGYUPDATE']._serialized_start=1069
  _globals['_ONTOLOGYUPDATE']._serialized_end=1460
  _globals['_ONTOLOGYLISTREQUEST']._serialized_start=1463
  _globals['_ONTOLOGYLISTREQUEST']._serialized_end=1600
  _globals['_ONTOLOGYLISTRESPONSE']._serialized_start=1602
  _globals['_ONTOLOGYLISTRESPONSE']._serialized_end=1724
  _globals['_ONTOLOGYGETREQUEST']._serialized_start=1726
  _globals['_ONTOLOGYGETREQUEST']._serialized_end=1822
  _globals['_ONTOLOGYGETRESPONSE']._serialized_start=1825
  _globals['_ONTOLOGYGETRESPONSE']._serialized_end=1955
  _globals['_ONTOLOGYCREATIONREQUEST']._serialized_start=1957
  _globals['_ONTOLOGYCREATIONREQUEST']._serialized_end=2028
  _globals['_ONTOLOGYCREATIONRESPONSE']._serialized_start=2031
  _globals['_ONTOLOGYCREATIONRESPONSE']._serialized_end=2166
  _globals['_ONTOLOGYUPDATEREQUEST']._serialized_start=2168
  _globals['_ONTOLOGYUPDATEREQUEST']._serialized_end=2235
  _globals['_ONTOLOGYUPDATERESPONSE']._serialized_start=2238
  _globals['_ONTOLOGYUPDATERESPONSE']._serialized_end=2371
  _globals['_ONTOLOGYDELETIONREQUEST']._serialized_start=2373
  _globals['_ONTOLOGYDELETIONREQUEST']._serialized_end=2452
  _globals['_ONTOLOGYDELETIONRESPONSE']._serialized_start=2454
  _globals['_ONTOLOGYDELETIONRESPONSE']._serialized_end=2533
  _globals['_ONTOLOGYSERVICE']._serialized_start=2536
  _globals['_ONTOLOGYSERVICE']._serialized_end=2941
# @@protoc_insertion_point(module_scope)
