# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chat.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
import common_pb2 as common__pb2
import naas_models.validate_pb2 as validate__pb2
import errors_pb2 as errors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nchat.proto\x12\x04\x63hat\x1a\x1cgoogle/protobuf/struct.proto\x1a\x0c\x63ommon.proto\x1a\x0evalidate.proto\x1a\x0c\x65rrors.proto\"\xd4\x04\n\x07Message\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12!\n\ncreated_at\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x02\x88\x01\x01\x12\x14\n\x07\x63hat_id\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x16\n\tfrom_user\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x14\n\x07message\x18\x06 \x01(\tH\x05\x88\x01\x01\x12#\n\x0cmessage_type\x18\x07 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x06\x88\x01\x01\x12\'\n\x10message_language\x18\x08 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x07\x88\x01\x01\x12\x15\n\x08model_id\x18\t \x01(\tH\x08\x88\x01\x01\x12$\n\x04type\x18\n \x01(\x0e\x32\x11.chat.MessageTypeH\t\x88\x01\x01\x12\x15\n\x08metadata\x18\x0b \x01(\tH\n\x88\x01\x01\x12!\n\ndeleted_at\x18\x0c \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x0b\x88\x01\x01\x12\x15\n\x08selected\x18\r \x01(\x08H\x0c\x88\x01\x01\x12\"\n\x0b\x61rchived_at\x18\x0e \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\r\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_versionB\r\n\x0b_created_atB\n\n\x08_chat_idB\x0c\n\n_from_userB\n\n\x08_messageB\x0f\n\r_message_typeB\x13\n\x11_message_languageB\x0b\n\t_model_idB\x07\n\x05_typeB\x0b\n\t_metadataB\r\n\x0b_deleted_atB\x0b\n\t_selectedB\x0e\n\x0c_archived_at\"\xdc\x02\n\rMessageUpdate\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12#\n\x0cmessage_type\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x01\x88\x01\x01\x12\'\n\x10message_language\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x02\x88\x01\x01\x12\x15\n\x08metadata\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08selected\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\"\n\x0b\x61rchived_at\x18\x06 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x05\x88\x01\x01\x12*\n\nfield_mask\x18\x64 \x01(\x0b\x32\x11.common.FieldMaskH\x06\x88\x01\x01\x42\n\n\x08_messageB\x0f\n\r_message_typeB\x13\n\x11_message_languageB\x0b\n\t_metadataB\x0b\n\t_selectedB\x0e\n\x0c_archived_atB\r\n\x0b_field_mask\"+\n\x08Messages\x12\x1f\n\x08messages\x18\x01 \x03(\x0b\x32\r.chat.Message\"R\n\x16MessageDeletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_version\"N\n\x17MessageDeletionResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xef\x01\n\rMessageRating\x12\x17\n\nmessage_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0fmessage_version\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x17\n\ncreated_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x12/\n\x06rating\x18\x05 \x01(\tB\x1a\xfa\x42\x17r\x15\x32\x10^(LIKE|DISLIKE)$\xd0\x01\x00H\x04\x88\x01\x01\x42\r\n\x0b_message_idB\n\n\x08_user_idB\x12\n\x10_message_versionB\r\n\x0b_created_atB\t\n\x07_rating\"\xb4\x01\n\x1cMessageRatingCreationRequest\x12\x17\n\nmessage_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1c\n\x0fmessage_version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12/\n\x06rating\x18\x03 \x01(\tB\x1a\xfa\x42\x17r\x15\x32\x10^(LIKE|DISLIKE)$\xd0\x01\x00H\x02\x88\x01\x01\x42\r\n\x0b_message_idB\x12\n\x10_message_versionB\t\n\x07_rating\"\x99\x01\n\x1dMessageRatingCreationResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12\x30\n\x0emessage_rating\x18\x02 \x01(\x0b\x32\x13.chat.MessageRatingH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x11\n\x0f_message_rating\"\xb6\x02\n\x04\x43hat\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x17\n\ncreated_at\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07user_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\ndeleted_at\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08is_group\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x17\n\nstarred_at\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\x05\n\x03_idB\r\n\x0b_created_atB\n\n\x08_user_idB\x07\n\x05_nameB\r\n\x0b_deleted_atB\x0b\n\t_is_groupB\x18\n\x16_is_personal_assistantB\r\n\x0b_starred_at\"\xed\x01\n\nChatUpdate\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08is_group\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x17\n\nstarred_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x12*\n\nfield_mask\x18\x64 \x01(\x0b\x32\x11.common.FieldMaskH\x04\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_is_groupB\x18\n\x16_is_personal_assistantB\r\n\x0b_starred_atB\r\n\x0b_field_mask\"\x83\x01\n\x0c\x43hatMessages\x12\x32\n\x08messages\x18\x01 \x03(\x0b\x32 .chat.ChatMessages.MessagesEntry\x1a?\n\rMessagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.chat.Messages:\x02\x38\x01\"o\n\x13\x43hatCreationRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_nameB\x18\n\x16_is_personal_assistant\"s\n\x14\x43hatCreationResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"(\n\x0e\x43hatGetRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"n\n\x0f\x43hatGetResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"/\n\x15\x43hatMessageGetRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"\x85\x01\n\x16\x43hatMessageGetResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12)\n\x08messages\x18\x02 \x01(\x0b\x32\x12.chat.ChatMessagesH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_messages\"-\n\x13\x43hatDeletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x42\x05\n\x03_id\"K\n\x14\x43hatDeletionResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"g\n\x11\x43hatUpdateRequest\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12*\n\x0b\x63hat_update\x18\x02 \x01(\x0b\x32\x10.chat.ChatUpdateH\x01\x88\x01\x01\x42\x05\n\x03_idB\x0e\n\x0c_chat_update\"q\n\x12\x43hatUpdateResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"a\n\x0f\x43hatListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"a\n\x10\x43hatListResponse\x12\x18\n\x04\x63hat\x18\x01 \x03(\x0b\x32\n.chat.Chat\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"E\n\x0f\x43hatStarRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04star\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_star\"o\n\x10\x43hatStarResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\",\n\x12\x43hatArchiveRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"J\n\x13\x43hatArchiveResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xa5\x02\n\x12\x43ompletionResponse\x12\x1f\n\x08messages\x18\x01 \x03(\x0b\x32\r.chat.Message\x12\x19\n\x0cinput_tokens\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1a\n\routput_tokens\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x1d\n\x10image_resolution\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0bimage_steps\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12+\n\x06status\x18\x06 \x01(\x0e\x32\x16.chat.CompletionStatusH\x04\x88\x01\x01\x42\x0f\n\r_input_tokensB\x10\n\x0e_output_tokensB\x13\n\x11_image_resolutionB\x0e\n\x0c_image_stepsB\t\n\x07_status\"c\n\x0b\x42\x61sePayload\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03url\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06prompt\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_nameB\x06\n\x04_urlB\t\n\x07_prompt\"\xa5\x01\n\x15\x43hatCompletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x15\n\x08model_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07payload\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\tplugin_id\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x03\x88\x01\x01\x42\x05\n\x03_idB\x0b\n\t_model_idB\n\n\x08_payloadB\x0c\n\n_plugin_id\"3\n\x19\x43hatStopCompletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"Q\n\x1a\x43hatStopCompletionResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x8f\x01\n\x16\x43hatCompletionResponse\x12\x31\n\ncompletion\x18\x01 \x01(\x0b\x32\x18.chat.CompletionResponseH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\r\n\x0b_completionB\x08\n\x06_error*\\\n\x0bMessageType\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x06\n\x02\x41I\x10\x02\x12\t\n\x05HUMAN\x10\x03\x12\x0e\n\nTOOL_USAGE\x10\x05\x12\x0f\n\x0bTOOL_ANSWER\x10\x06*:\n\x10\x43ompletionStatus\x12\r\n\tCOMPLETED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x0b\n\x07TIMEOUT\x10\x02\x32\xfa\x02\n\x0b\x43hatService\x12\x41\n\x06\x43reate\x12\x19.chat.ChatCreationRequest\x1a\x1a.chat.ChatCreationResponse\"\x00\x12\x34\n\x03Get\x12\x14.chat.ChatGetRequest\x1a\x15.chat.ChatGetResponse\"\x00\x12\x37\n\x04List\x12\x15.chat.ChatListRequest\x1a\x16.chat.ChatListResponse\"\x00\x12\x41\n\x06\x44\x65lete\x12\x19.chat.ChatDeletionRequest\x1a\x1a.chat.ChatDeletionResponse\"\x00\x12=\n\x06Update\x12\x17.chat.ChatUpdateRequest\x1a\x18.chat.ChatUpdateResponse\"\x00\x12\x37\n\x04Star\x12\x15.chat.ChatStarRequest\x1a\x16.chat.ChatStarResponse\"\x00\x42-Z+github.com/jupyter-naas/naas-models/go/chatb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chat_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/jupyter-naas/naas-models/go/chat'
  _globals['_MESSAGE'].fields_by_name['created_at']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['created_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['message_type']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['message_type']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['message_language']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['message_language']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['deleted_at']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['deleted_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['archived_at']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['archived_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGEUPDATE'].fields_by_name['message_type']._loaded_options = None
  _globals['_MESSAGEUPDATE'].fields_by_name['message_type']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGEUPDATE'].fields_by_name['message_language']._loaded_options = None
  _globals['_MESSAGEUPDATE'].fields_by_name['message_language']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGEUPDATE'].fields_by_name['archived_at']._loaded_options = None
  _globals['_MESSAGEUPDATE'].fields_by_name['archived_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGERATING'].fields_by_name['rating']._loaded_options = None
  _globals['_MESSAGERATING'].fields_by_name['rating']._serialized_options = b'\372B\027r\0252\020^(LIKE|DISLIKE)$\320\001\000'
  _globals['_MESSAGERATINGCREATIONREQUEST'].fields_by_name['rating']._loaded_options = None
  _globals['_MESSAGERATINGCREATIONREQUEST'].fields_by_name['rating']._serialized_options = b'\372B\027r\0252\020^(LIKE|DISLIKE)$\320\001\000'
  _globals['_CHATMESSAGES_MESSAGESENTRY']._loaded_options = None
  _globals['_CHATMESSAGES_MESSAGESENTRY']._serialized_options = b'8\001'
  _globals['_CHATCOMPLETIONREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_CHATCOMPLETIONREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_MESSAGETYPE']._serialized_start=4785
  _globals['_MESSAGETYPE']._serialized_end=4877
  _globals['_COMPLETIONSTATUS']._serialized_start=4879
  _globals['_COMPLETIONSTATUS']._serialized_end=4937
  _globals['_MESSAGE']._serialized_start=95
  _globals['_MESSAGE']._serialized_end=691
  _globals['_MESSAGEUPDATE']._serialized_start=694
  _globals['_MESSAGEUPDATE']._serialized_end=1042
  _globals['_MESSAGES']._serialized_start=1044
  _globals['_MESSAGES']._serialized_end=1087
  _globals['_MESSAGEDELETIONREQUEST']._serialized_start=1089
  _globals['_MESSAGEDELETIONREQUEST']._serialized_end=1171
  _globals['_MESSAGEDELETIONRESPONSE']._serialized_start=1173
  _globals['_MESSAGEDELETIONRESPONSE']._serialized_end=1251
  _globals['_MESSAGERATING']._serialized_start=1254
  _globals['_MESSAGERATING']._serialized_end=1493
  _globals['_MESSAGERATINGCREATIONREQUEST']._serialized_start=1496
  _globals['_MESSAGERATINGCREATIONREQUEST']._serialized_end=1676
  _globals['_MESSAGERATINGCREATIONRESPONSE']._serialized_start=1679
  _globals['_MESSAGERATINGCREATIONRESPONSE']._serialized_end=1832
  _globals['_CHAT']._serialized_start=1835
  _globals['_CHAT']._serialized_end=2145
  _globals['_CHATUPDATE']._serialized_start=2148
  _globals['_CHATUPDATE']._serialized_end=2385
  _globals['_CHATMESSAGES']._serialized_start=2388
  _globals['_CHATMESSAGES']._serialized_end=2519
  _globals['_CHATMESSAGES_MESSAGESENTRY']._serialized_start=2456
  _globals['_CHATMESSAGES_MESSAGESENTRY']._serialized_end=2519
  _globals['_CHATCREATIONREQUEST']._serialized_start=2521
  _globals['_CHATCREATIONREQUEST']._serialized_end=2632
  _globals['_CHATCREATIONRESPONSE']._serialized_start=2634
  _globals['_CHATCREATIONRESPONSE']._serialized_end=2749
  _globals['_CHATGETREQUEST']._serialized_start=2751
  _globals['_CHATGETREQUEST']._serialized_end=2791
  _globals['_CHATGETRESPONSE']._serialized_start=2793
  _globals['_CHATGETRESPONSE']._serialized_end=2903
  _globals['_CHATMESSAGEGETREQUEST']._serialized_start=2905
  _globals['_CHATMESSAGEGETREQUEST']._serialized_end=2952
  _globals['_CHATMESSAGEGETRESPONSE']._serialized_start=2955
  _globals['_CHATMESSAGEGETRESPONSE']._serialized_end=3088
  _globals['_CHATDELETIONREQUEST']._serialized_start=3090
  _globals['_CHATDELETIONREQUEST']._serialized_end=3135
  _globals['_CHATDELETIONRESPONSE']._serialized_start=3137
  _globals['_CHATDELETIONRESPONSE']._serialized_end=3212
  _globals['_CHATUPDATEREQUEST']._serialized_start=3214
  _globals['_CHATUPDATEREQUEST']._serialized_end=3317
  _globals['_CHATUPDATERESPONSE']._serialized_start=3319
  _globals['_CHATUPDATERESPONSE']._serialized_end=3432
  _globals['_CHATLISTREQUEST']._serialized_start=3434
  _globals['_CHATLISTREQUEST']._serialized_end=3531
  _globals['_CHATLISTRESPONSE']._serialized_start=3533
  _globals['_CHATLISTRESPONSE']._serialized_end=3630
  _globals['_CHATSTARREQUEST']._serialized_start=3632
  _globals['_CHATSTARREQUEST']._serialized_end=3701
  _globals['_CHATSTARRESPONSE']._serialized_start=3703
  _globals['_CHATSTARRESPONSE']._serialized_end=3814
  _globals['_CHATARCHIVEREQUEST']._serialized_start=3816
  _globals['_CHATARCHIVEREQUEST']._serialized_end=3860
  _globals['_CHATARCHIVERESPONSE']._serialized_start=3862
  _globals['_CHATARCHIVERESPONSE']._serialized_end=3936
  _globals['_COMPLETIONRESPONSE']._serialized_start=3939
  _globals['_COMPLETIONRESPONSE']._serialized_end=4232
  _globals['_BASEPAYLOAD']._serialized_start=4234
  _globals['_BASEPAYLOAD']._serialized_end=4333
  _globals['_CHATCOMPLETIONREQUEST']._serialized_start=4336
  _globals['_CHATCOMPLETIONREQUEST']._serialized_end=4501
  _globals['_CHATSTOPCOMPLETIONREQUEST']._serialized_start=4503
  _globals['_CHATSTOPCOMPLETIONREQUEST']._serialized_end=4554
  _globals['_CHATSTOPCOMPLETIONRESPONSE']._serialized_start=4556
  _globals['_CHATSTOPCOMPLETIONRESPONSE']._serialized_end=4637
  _globals['_CHATCOMPLETIONRESPONSE']._serialized_start=4640
  _globals['_CHATCOMPLETIONRESPONSE']._serialized_end=4783
  _globals['_CHATSERVICE']._serialized_start=4940
  _globals['_CHATSERVICE']._serialized_end=5318
# @@protoc_insertion_point(module_scope)
